@@ -10,11 +10,17 @@ from datetime import datetime, date, timedelta
 from dateutil.relativedelta import relativedelta
 
 from fmqlutils.cacher.cacherUtils import TMPWORKING_LOCN_TEMPL, FMQLReplyStore, FilteredResultIterator, DATA_LOCN_TEMPL, metaOfVistA
-from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent
-from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, checkDataPresent, singleValue, combineSubTypes, muBVC, muBVCOfSTProp
+from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent, muBVC
+from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, checkDataPresent, singleValue, combineSubTypes, muBVCOfSTProp
 
 from ..webReportUtils import TOP_MD_TEMPL, SITE_DIR_TEMPL, ensureWebReportLocations, keyStats, flattenFrequencyDistribution, roundFloat, reduce200, flattenPropValues
 
+"""
+TODO: ac finish
+- 4 way service including enforce for routing
+  ... and need reduce4 so using stationNo
+"""
+
 """
 Report TeleReading and the supporting IFCs, documents and images. Very particular IFC.
 Cover [1] both Acquisition and Reader sides (including when they are the same VistA) and
@@ -86,14 +92,14 @@ def webReportTeleReading(stationNo, stationName, onAndAfterDay, upToDay):
         {"fileType": "123_5", "check": "ALL"},
 
         # For User Identification
-        {"fileType": "200", "check": "ALL"},
+        # 200 - reduce200 will enforce need for 200
         {"fileType": "3_081", "check": "YR1E"}
         
     ])
     if not allThere:
         raise Exception("Some required data is missing - {}".format(details))
 
-    mu = TOP_MD_TEMPL.format("{} TeleReader".format(stationNo), "TeleReader")
+    mu = TOP_MD_TEMPL.format("{} TeleReader".format(stationNo))
 
     mu += """# Telereader
    
@@ -145,7 +151,7 @@ def webReportAcquisition(stationNo, onAndAfterDay, upToDay):
 
     # 123 and 2006_5849 reductions
     type123YR1, sts123YR1 = splitTypeDatas(stationNo, "123", reductionLabel="YR1", )
-    type2006_5849YR1E, sts2006_5849YR1E = splitTypeDatas(stationNo, "2006_5849", reductionLabel="YR1E", expectSubTypeProperties=["reader_duz_at_acquisition_site", "image_index_for_specialty", "consult_service", "status"])
+    type2006_5849YR1E, sts2006_5849YR1E = splitTypeDatas(stationNo, "2006_5849", reductionLabel="YR1E", expectSubTypeProperties=["reader_duz_at_acquisition_site", "image_index_for_specialty", "consult_service", "status", "#reading_start"])
     
     # Group per User (and don't want the one possible, no user specified)
     st2006_5849Us = [st for st in combineSubTypes(sts2006_5849YR1E, ["reader_duz_at_acquisition_site"], forceCountProps=["consult_service"]) if "reader_duz_at_acquisition_site" in st]
@@ -179,18 +185,18 @@ def webReportAcquisition(stationNo, onAndAfterDay, upToDay):
     - 2006_5849 YR1E Red for total queue entries: all have unique consult and
     with E embedding consult properties, can describe the consult of queue entries
     from the queue reduction
+
+    # Placer Total Consults if want to use these.
+        reportAbsAndPercent(
+            type123YR1["ifc_role"]["byValueCount"]["P:Placer"],
+            type123YR1["_total"]
+        ) if "ifc_role" in type2006_5849YR1E else 0,
     """
     consultIFCCount = type2006_5849YR1E["is_consult_ifc"]["count"] if "is_consult_ifc" in type2006_5849YR1E else 0
     mu += """An _Acquisition site_ imports images and submits them for telereading \"consults\". These are tracked in _TELEREADER READ/UNREAD LIST (2006.5849)_. In this site. There are <span class='countHigh'>{:,}</span> total consults between {} and {}. Of these, <span class='countHigh'>{}</span> are in this LIST, <span class='countHigh'>{}</span> of these are interfacility consults (IFCs), where another facility performs the consult while the balance, <span class='countHigh'>{}</span>, are performed locally.
     
 """.format(
         type123YR1["_total"],
-        """ # Placer Total Consults if want to use these.
-        reportAbsAndPercent(
-            type123YR1["ifc_role"]["byValueCount"]["P:Placer"], 
-            type123YR1["_total"]
-        ) if "ifc_role" in type2006_5849YR1E else 0,
-        """
         onAndAfterDay, 
         upToDay,
         # count of queue consults == count of queue entries as 1-1
@@ -258,7 +264,7 @@ def webReportAcquisition(stationNo, onAndAfterDay, upToDay):
         status = singleValue(st, "status")
         st2006_5849ByStatus[status].append(st)
     # , ":Added Comments"
-    tbl = MarkdownTable([":Status", ":Transitions", "Count", "Reading Site"], includeNo=False)
+    tbl = MarkdownTable([":Status", ":Transitions", "Count", ":Reading Site"], includeNo=False)
     currentStatus = ""
     for status in ["W:Waiting", "U:Unread", "C:Cancelled", "L:Locked", "D:Deleted", "R:Read"]:
         if status not in st2006_5849ByStatus:
@@ -423,8 +429,11 @@ Its <span class='countHigh'>{:,}</span> entries belong to <span class='countHigh
         propMap = [("name", "Service", "DROP"), ("acquisition_site", "Acquisition Site", "IEN"), ("procedure_index", "Procedure Index", "DROP"), ("unread_list_creation_trigger", "Creation Trigger"), ("tiu_note_file", "TIU Note")]
         for si in sorted(bySpecialtyIndex):
             suppress=["specialty_index", "procedure"]
+            """
+            KEEP it as suppression is working for col but not row entry!
             if len(set(resource["acquisition_site"] for resource in bySpecialtyIndex[si])) != len(bySpecialtyIndex[si]):
                 suppress.append("acquisition_site")
+            """
             tbl = MarkdownTable([":{}".format(pmap[1]) for pmap in propMap if pmap[0] not in suppress])
             for resource in bySpecialtyIndex[si]:            
                 tbl.addRow(rowUp(resource, propMap, True, suppress=suppress))
