@@ -487,9 +487,7 @@ class UserClassifier:
             self.__result["remoteExcludeReasonCount"]["MAND_PROPS"] += 1
             missingMands = (UserClassifier.PUREZEROSOCREATEDUSER_200_MAND_PROPS - set(userInfo["hasProps"])) - set(["secondary_menu_options", "timestamp", "alias"])
             if len(missingMands) != 0:
-                raise Exception("At this point in Remote Check, only expected mandatory SMO/ TimeStamp/ Alias could be missing but {}".format(
-                                    "/".join(list(missingMands))
-                                ))
+                self.__result["warningsByUserRef"][userRef].append("At this point in Remote Check, only expected mandatory SMO/ TimeStamp/ Alias could be missing but {}".format("/".join(list(missingMands))))
             return False
             
         if "ssn" not in userInfo and sum(1 for vf in userInfo["signed_on_froms"] if re.match(r'358\:', vf)) == 0:
