@@ -7,11 +7,9 @@ import re
 import json
 from collections import defaultdict, Counter
 from datetime import datetime, date
-import numpy
 
-from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent
-
-from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, checkDataPresent, singleValue, combineSubTypes, muBVC, muBVCOfSTProp
+from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent, muBVC
+from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, checkDataPresent, singleValue, combineSubTypes, muBVCOfSTProp
 
 from ..webReportUtils import TOP_MD_TEMPL, SITE_DIR_TEMPL, ensureWebReportLocations, keyStats, flattenFrequencyDistribution, roundFloat, reduce200
 from .userClassifier import UserClassifier
@@ -40,8 +38,7 @@ def webReportUser(stationNo, deidentify=False):
         # - duration (in seconds) 
         # - force count on 
         #     ipv4_address, remote_station_id, remote_user_ien, duration
-        {"fileType": "3_081", "check": "YR1E"},
-        {"fileType": "200", "check": "ALL"} # Index
+        {"fileType": "3_081", "check": "YR1E"}
     ])
     if not allThere:
         raise Exception("Some required data is missing - {}".format(details))
