@@ -9,9 +9,9 @@ from collections import defaultdict, Counter
 from datetime import datetime, timedelta
 from dateutil.relativedelta import relativedelta
 
-from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent
+from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent, muBVC
 from fmqlutils.cacher.cacherUtils import metaOfVistA, TMPWORKING_LOCN_TEMPL, FMQLReplyStore, FilteredResultIterator, DATA_LOCN_TEMPL 
-from fmqlutils.typer.reduceTypeUtils import checkDataPresent, muBVC, muBVCOfSTProp
+from fmqlutils.typer.reduceTypeUtils import checkDataPresent, muBVCOfSTProp
 
 from ..webReportUtils import TOP_MD_TEMPL, SITE_DIR_TEMPL, ensureWebReportLocations, keyStats, roundFloat, reduce44, filteredResultIterator, flattenPropValues
         
