@@ -7,11 +7,10 @@ import re
 import json
 from collections import defaultdict, Counter
 from datetime import datetime
-import numpy
 
-from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent
+from fmqlutils.reporter.reportUtils import MarkdownTable, reportPercent, reportAbsAndPercent, muBVC
 from fmqlutils.cacher.cacherUtils import metaOfVistA
-from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, combineSubTypes, checkDataPresent, singleValue, muBVC, muBVCOfSTProp
+from fmqlutils.typer.reduceTypeUtils import splitTypeDatas, combineSubTypes, checkDataPresent, singleValue, muBVCOfSTProp
 
 from ..webReportUtils import filteredResultIterator, reduce200, reduce4, reduce44, TOP_MD_TEMPL, SITE_DIR_TEMPL, ensureWebReportLocations, keyStats, roundFloat
 
