@@ -6,18 +6,18 @@ import os
 import re
 import json
 from collections import defaultdict, Counter
+import statistics
 
-import numpy
-import math
-
+from fmqlutils import VISTA_DATA_BASE_DIR
 from fmqlutils.cacher.cacherUtils import FMQLReplyStore, FilteredResultIterator, SCHEMA_LOCN_TEMPL, DATA_LOCN_TEMPL, DATARF_LOCN_TEMPL, TMPWORKING_LOCN_TEMPL
+from fmqlutils.typer.reduceTypeUtils import checkDataPresent
 from fmqlutils.typer.reduceReportType import TYPER_REDUCTIONS_LOCN_TEMPL
 from fmqlutils.reporter.reportUtils import MarkdownTable
 
 """
 Site
 """
-SITE_DIR_TEMPL = "/data/vista/{}/ReportSite/" 
+SITE_DIR_TEMPL = VISTA_DATA_BASE_DIR + "{}/ReportSite/" 
 
 TOP_MD_TEMPL = """---
 layout: default
@@ -51,7 +51,7 @@ Shows off key stats with a little (obvious) stats observations
 
 https://docs.scipy.org/doc/numpy/user/
 
-TODO: more on numpy (ie/ go through it as go through books)
+TODO: more on statistics (and numpy?) ... median_low etc for rounded
 """
 def reportKeyStats(kstats):
     print("Count Values: {}".format(kstats["count"]))
@@ -74,6 +74,9 @@ def reportKeyStats(kstats):
 """
 Key stats for distribution of values
 
+TODO: fully expand on statistics (median_low etc) and not just numpy repeat
+(method= ...)
+
 min, max
 Quartile: 1, 2 (Median), 3 for data-spread
 ... "five-number summary" ideal for data w/ outliers and a 'box-and-whisker' plot 
@@ -100,11 +103,12 @@ https://en.wikipedia.org/wiki/Outlier (Tukey's fences)
 - above: Q3 + K(Q3-Q1) where K is 1.5 and K = 3 is "far out"
 - below: Q1 - K(Q1-Q3)
 ie/ K times Quartile. Fences for box plots.
-"""
+"""    
 def keyStats(values):
-    quartileOne = numpy.percentile(values, 25)
-    median = numpy.percentile(values, 50)
-    quartileThree = numpy.percentile(values, 75)
+    quartiles = statistics.quantiles(values, method="inclusive") # inc matched numpy
+    quartileOne = quartiles[0] # numpy.percentile(values, 25)
+    median = quartiles[1] # numpy.percentile(values, 50)
+    quartileThree = quartiles[2] # numpy.percentile(values, 75)
     # get variance in middle 50% of data
     # numpy.subtract(*numpy.percentile(values, [75, 25]))
     iqr = quartileThree - quartileOne # interquartile range    
@@ -112,7 +116,9 @@ def keyStats(values):
     cntValsGTOHT = sum(1 for val in values if val > oht) 
     ohto = quartileThree + (3 * iqr) # idea of "outer fence": TODO: get name
     cntValsGTOHTO = sum(1 for val in values if val > ohto) 
-    stats = {"total": sum(val for val in values), "count": len(values), "min": numpy.min(values), "quartileOne": quartileOne, "median": median, "quartileThree": quartileThree, "max": numpy.max(values), "iqr": iqr, "oht": oht, "ohto": ohto, "mean": numpy.mean(values), "std": numpy.std(values)}
+    mx = sorted(values)[-1] # numpy.max(values)
+    mn = sorted(values)[0] # numpy.min(values)
+    stats = {"total": sum(val for val in values), "count": len(values), "min": mn, "quartileOne": quartileOne, "median": median, "quartileThree": quartileThree, "max": mx, "iqr": iqr, "oht": oht, "ohto": ohto, "mean": statistics.mean(values), "std": statistics.stdev(values)}
     olt = quartileOne - (1.5 * iqr) # Outlier Low below this
     if int(olt) > 0: # only olt if > 0 ie/ negative ie/ all acceptable
         stats["olt"] = olt
@@ -231,6 +237,16 @@ def reduce200(stationNo, onlyUsers=None, forceNew=False, coreOnly=False):
         else:
             return infosByRef
 
+    allThere, details = checkDataPresent(stationNo, [
+        # Additional settings/properties:
+        # - duration (in seconds)
+        # - force count on
+        #     ipv4_address, remote_station_id, remote_user_ien, duration
+        {"fileType": "200", "check": "ALL"} # Index
+    ])
+    if not allThere:
+        raise Exception("Some required data is missing - {}".format(details))
+
     print("First time through, creating index by id for Users (200) for {}".format(stationNo))
     
     dataLocn = DATA_LOCN_TEMPL.format(stationNo)
@@ -407,8 +423,28 @@ def reduce2(stationNo, forceNew=False):
         # TODO: expand these - ensure all id's used by VA/C are in here
         "integration_control_number", 
         "subscription_control_number", # 774 entries for CIRN (see if sync file
-        "full_icn"    
+        "full_icn",
+        "primary_long_id", # see queue on where differs from SSN
+        "primary_short_id" # may be redundant but get to see   
     ])
+    """
+    What should be
+    - short_id == end of long_id
+    - long_id == - version of ssn ie/ 111-22-3333 vs 111223333
+    - icn is first part of full_icn
+    ... ie/ nixing redundancies
+    """
+    def cutIds(info):
+        if "integration_control_number" in info:
+            if "full_icn" in info and info["integration_control_number"] == info["full_icn"].split("V")[0]:
+                del info["integration_control_number"]
+        if "primary_short_id" in info:
+            if "primary_long_id" in info and info["primary_short_id"] == info["primary_long_id"].split("-")[-1]:
+                del info["primary_short_id"]
+        # in WWW, only if bug
+        if "social_security_number" in info and "primary_long_id" in info:
+            if info["social_security_number"] == re.sub(r'\-', "", info["primary_long_id"]):
+                del info["primary_long_id"]
     for resource in resourceIter:
         patientIEN = resource["_id"].split("-")[1]
         info = {"ien": patientIEN}
@@ -423,12 +459,13 @@ def reduce2(stationNo, forceNew=False):
                         info[prop] = resource[prop]["label"]
                 else: 
                     info[prop] = resource[prop]
+        cutIds(info)
         infosByIEN[patientIEN] = info
         if len(infosByIEN) % 1000 == 0:
             print("Processed another 1000 patients - now at {:,}".format(len(infosByIEN)))
             sys.stdout.flush()
     
-    print("Serializing and Returning Index of {:,} Users (2)".format(len(infosByIEN)))
+    print("Serializing and Returning Index of {:,} Patients (2)".format(len(infosByIEN)))
     sys.stdout.flush()
 
     json.dump(infosByIEN, open(jsnFl, "w"), indent=4)
